#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.2
visibility:           public
id:                   aws-0.24.2-FS75iFI7kRBCrMNOWsHeX0
key:                  aws-0.24.2-FS75iFI7kRBCrMNOWsHeX0
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  5ac12110b4407fd13423796d24470494
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.2-FS75iFI7kRBCrMNOWsHeX0
depends:
    aeson-2.2.1.0-AYdtcmOjw9uLjZBMGVgJqG
    attoparsec-0.14.4-8yfReFQVnRV5DMGjEfnPOW
    attoparsec-aeson-2.2.0.0-Al2UzSEXUzyGa2dSdC9WdT base-4.18.2.1
    base16-bytestring-1.0.2.0-EQipqCKv7X46z29erFjOBi
    base64-bytestring-1.2.1.0-7Dsh2HoU9pUKnPpyGeO0o2
    blaze-builder-0.4.4.1-4CgMVSSAKshGOQs3yJAkdr
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    case-insensitive-1.2.1.0-L8b71mleMbHJVaC8zF8N1a
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    conduit-1.3.6.1-L3lTj8wXwAg9DCl2a74QFC
    conduit-extra-1.3.8-K8fr8BgZVrn7TcdffNnPjc containers-0.6.7
    cryptonite-0.30-LrEU6U7Xer3GhOkQdtd9h8
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-tls-0.3.6.4-3i0tj6Kth1D3ViG9sfroXw
    http-conduit-2.3.9.1-Ee7z5O8XsoN5RVuiPdgJju
    http-types-0.12.4-8B17I1n2XHHHcNbNp9otXd
    lifted-base-0.2.3.12-6VZ0ECm1lDn92gmf8v8YO3
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-control-1.0.3.1-7xrJc81SCp2JkhcpwQsEqa mtl-2.3.1
    network-3.1.4.0-F5hgFLxNbdiMTTF4ZJb4k
    network-bsd-2.8.1.0-DWUzjFH0jhh5nZPbgJ5zjA
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    resourcet-1.2.6-1dVGp7EZq0UYuER60YSQJ
    safe-0.3.21-4ZJVmlIlgWv2xHWSCfZbih
    scientific-0.3.8.1-CDKE6rvpzK9Lobow8aNDlb
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9wZ7uB8CqcR5TZZg4U4qth
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-Is51f3ml4GnGFciyGIODi
    xml-conduit-1.9.1.4-ALlsjnWj6Uk3eC68frpZOt

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

